==> NumberSequences-0.8.tar.gz: NumberSequences-0.8/setup.py <==
from distutils.core import setup
setup(
  name = 'NumberSequences',         # How you named your package folder (MyLib)
  packages = ['NumberSequences'],   # Chose the same as "name"
  version = '0.8',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Tools for generating number sequences',   # Give a short description about your library
  long_description= 'Tools for generating number sequences and learning more about them',
  author = 'Robbie Dee',                   # Type in your name
  author_email = 'admin@staticola.com',      # Type in your E-Mail
  url = 'http://staticola.com',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['MATH', 'NUMBERS', 'FUN'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second          
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Scientific/Engineering :: Mathematics',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> NumberSequences-0.10.tar.gz: NumberSequences-0.10/setup.py <==
from distutils.core import setup
import setuptools

with open('README.rst') as f:
    readme = f.read()

setup(
  name = 'NumberSequences',         # How you named your package folder (MyLib)
  packages = ['NumberSequences'],   # Chose the same as "name"
  version = '0.10',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Tools for generating number sequences',   # Give a short description about your library
  long_description= readme,
  long_description_content_type = 'text/markdown',
  author = 'Robbie Dee',                   # Type in your name
  author_email = 'admin@staticola.com',      # Type in your E-Mail
  url = 'http://staticola.com',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['MATH', 'NUMBERS', 'FUN'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second          
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Scientific/Engineering :: Mathematics',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
